DecapKey

Struct DecapKey 

pub struct DecapKey {
    ml: DecapsulationKey,
    ml_ek: EncapsulationKey,
    ec: PrivateKey,
}
Decapsulation key, the ‘private key’ of the KEM. Generate using DecapKey::generate.

Fields

ml: DecapsulationKeyml_ek: EncapsulationKey

Cached ML-KEM encapsulation key.

The mlkem::DecapsulationKey type is a bit weird: it either contains just the decapsulation key (when read from bytes via mlkem::DecapsulationKey::new or it contains both an encapsulation and decapsulation key (when generated via mlkem::DecapsulationKey::generate.)

So to deal with the former case, we include the encapsulation key here as well.

ec: PrivateKey

Implementations

Source

impl DecapKey

pub fn generate() -> Result<Self, Opaque>

Generates a DecapKey. Expensive.

pub fn encap_key(&self) -> EncapKey

Returns the associated EncapKey. Deterministic and cheap.

pub fn decap(&self, ct: &CiphertextBytes) -> Result<SharedSecret, Opaque>

Decapsulates ciphertext, recovering the SharedSecret within. Expensive.

pub fn encode(&self) -> Result<DecapKeyBytes, Opaque>

Encodes for storage.