pub struct DecapKey {
ml: DecapsulationKey,
ml_ek: EncapsulationKey,
ec: PrivateKey,
}Expand description
Decapsulation key, the ‘private key’ of the KEM. Generate using DecapKey::generate.
Fields
ml: DecapsulationKeyml_ek: EncapsulationKeyCached ML-KEM encapsulation key.
The mlkem::DecapsulationKey type is a bit weird: it either contains just the
decapsulation key (when read from bytes via mlkem::DecapsulationKey::new or
it contains both an encapsulation and decapsulation key (when generated via
mlkem::DecapsulationKey::generate.)
So to deal with the former case, we include the encapsulation key here as well.
ec: PrivateKeyImplementations
Sourceimpl DecapKey
impl DecapKey
Sourcepub fn decap(&self, ct: &CiphertextBytes) -> Result<SharedSecret, Opaque>
pub fn decap(&self, ct: &CiphertextBytes) -> Result<SharedSecret, Opaque>
Decapsulates ciphertext, recovering the SharedSecret within. Expensive.
Sourcepub fn encode(&self) -> Result<DecapKeyBytes, Opaque>
pub fn encode(&self) -> Result<DecapKeyBytes, Opaque>
Encodes for storage.